@@ -25,6 +25,8 @@ __docformat__ = "restructuredtext en"
 import sys
 import logging
 
+from logilab.common.modutils import load_module_from_name
+
 _LOGGER = logging.getLogger('logilab.database')
 
 USE_MX_DATETIME = False
@@ -33,7 +35,7 @@ _PREFERED_DRIVERS = {}
 _ADV_FUNC_HELPER_DIRECTORY = {}
 
 def _ensure_module_loaded(driver):
-    if driver in ('postgres', 'sqlite', 'mysql', 'sqlserver'):
+    if driver in ('postgres', 'sqlite', 'mysql', 'sqlserver2005'):
         __import__('logilab.database.%s' % driver)
 # main functions ###############################################################
 
@@ -60,7 +62,7 @@ def get_connection(driver='postgres', host='', database='', user='',
                   pywrap=False, extra_args=None):
     """return a db connection according to given arguments"""
     _ensure_module_loaded(driver)
-    module, modname = _import_driver_module(driver, drivers, ['connect'])
+    module, modname = _import_driver_module(driver, drivers)
     try:
         adapter = _ADAPTER_DIRECTORY.get_adapter(driver, modname)
     except NoAdapterFound, err:
@@ -148,7 +150,7 @@ _ADAPTER_DIRECTORY = _AdapterDirectory()
 del _AdapterDirectory
 
 
-def _import_driver_module(driver, drivers, imported_elements=None, quiet=True):
+def _import_driver_module(driver, drivers, quiet=True):
     """Imports the first module found in 'drivers' for 'driver'
 
     :rtype: tuple
@@ -157,12 +159,11 @@ def _import_driver_module(driver, drivers, imported_elements=None, quiet=True):
     """
     if not driver in drivers:
         raise UnknownDriver(driver)
-    imported_elements = imported_elements or []
     for modname in drivers[driver]:
         try:
             if not quiet:
                 print >> sys.stderr, 'Trying %s' % modname
-            module = __import__(modname, globals(), locals(), imported_elements)
+            module = load_module_from_name(modname, use_sys=False)
             break
         except ImportError:
             if not quiet:
@@ -170,9 +171,6 @@ def _import_driver_module(driver, drivers, imported_elements=None, quiet=True):
             continue
     else:
         raise ImportError('Unable to import a %s module' % driver)
-    if not imported_elements:
-        for part in modname.split('.')[1:]:
-            module = getattr(module, part)
     return module, modname
 
 
@@ -408,7 +406,13 @@ class RANDOM(FunctionDescr):
     name_mapping = {'postgres': 'RANDOM',
                     'mysql': 'RAND',
                     }
-
+class SUBSTRING(FunctionDescr):
+    rtype = 'String'
+    minargs = maxargs = 3
+    name_mapping = {'postgres': 'SUBSTR',
+                    'mysql': 'SUBSTRING',
+                    'sqlite': 'SUBSTR',
+                    'sqlserver': 'SUBSTRING'}
 
 class ExtractDateField(FunctionDescr):
     rtype = 'Int'
@@ -482,7 +486,7 @@ for func_class in (
     MIN, MAX, SUM, COUNT, AVG,
     # transformation functions
     UPPER, LOWER, LENGTH, DATE, RANDOM,
-    YEAR, MONTH, DAY, HOUR, MINUTE, SECOND,
+    YEAR, MONTH, DAY, HOUR, MINUTE, SECOND, SUBSTRING,
     # keyword function
     IN):
     SQL_FUNCTIONS_REGISTRY.register_function(func_class())
@@ -656,8 +660,18 @@ INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
         return 'ALTER TABLE %s ALTER COLUMN %s %s NOT NULL' % (
             table, column, cmd)
 
+    def temporary_table_name(self, table_name):
+        """
+        return a temporary table name constructed from the table_name argument
+        (e.g. for SQL Server, prepend a '#' to the name)
+        Standard implementation returns the argument unchanged. 
+        """
+        return table_name
+
+
     def sql_temporary_table(self, table_name, table_schema,
                             drop_on_commit=True):
+        table_name = self.temporary_table_name(table_name)
         return "CREATE TEMPORARY TABLE %s (%s);" % (table_name, table_schema)
 
     def boolean_value(self, value):
