@@ -8,7 +8,7 @@ __docformat__ = "restructuredtext en"
 
 distname = 'logilab-database'
 modname = 'database'
-numversion = (1, 0, 0)
+numversion = (1, 0, 2)
 version = '.'.join([str(num) for num in numversion])
 copyright = '2000-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.'
 license = 'GPL'
@@ -36,6 +36,4 @@ mailinglist = "mailto://python-projects@lists.logilab.org"
 subpackage_of = 'logilab'
 subpackage_master = True
 
-from os.path import join
-include_dirs = [join('test', 'data')]
 pyversions = ['2.4', '2.5', '2.6']
